# Copyright (C) 2005-2008 Osmo Salomaa
#
# This file is part of Gaupol.
#
# Gaupol is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# Gaupol. If not, see <http://www.gnu.org/licenses/>.

import gaupol.gtk
import gtk


class TestApplication(gaupol.gtk.TestCase):

    def run__application(self):

        gtk.main()

    def setup_method(self, method):

        self.conf = gaupol.gtk.conf.application_window
        self.application = gaupol.gtk.Application()

    def test___init__(self):

        self.conf.toolbar_style = gaupol.gtk.toolbar_styles.ICONS
        self.conf.maximized = True
        self.application = gaupol.gtk.Application()
